@@ -37,7 +37,7 @@
                  [org.clojure/tools.nrepl "0.2.0-beta2"]
                  [swank-clojure "1.4.0"]
                  [clj-stacktrace "0.2.4"]
-                 [metrics-clojure "0.7.0"]
+                 [metrics-clojure "0.7.0" :exclusions [org.clojure/clojure org.slf4j/slf4j-api]]
                  [clj-time "0.3.7"]
                  [org.clojure/java.jmx "0.1"]
                  ;; Filesystem utilities
@@ -52,20 +52,20 @@
                                               com.sun.jdmk/jmxtools
                                               com.sun.jmx/jmxri]]
                  ;; Database connectivity
-                 [com.jolbox/bonecp "0.7.1.RELEASE"]
-                 [org.slf4j/slf4j-log4j12 "1.5.6"]
+                 [com.jolbox/bonecp "0.7.1.RELEASE" :exclusions [org.slf4j/slf4j-api]]
+                 [org.slf4j/slf4j-log4j12 "1.6.4"]
                  [org.clojure/java.jdbc "0.1.1"]
                  [org.hsqldb/hsqldb "2.2.8"]
                  [postgresql/postgresql "9.0-801.jdbc4"]
                  [clojureql "1.0.3"]
                  ;; MQ connectivity
-                 [clamq/clamq-activemq "0.4"]
-                 [org.apache.activemq/activemq-core "5.5.1"]
+                 [clamq/clamq-activemq "0.4" :exclusions [org.slf4j/slf4j-api]]
+                 [org.apache.activemq/activemq-core "5.5.1" :exclusions [org.slf4j/slf4j-api]]
                  ;; WebAPI support libraries.
                  [net.cgrand/moustache "1.1.0"]
                  [clj-http "0.3.1"]
-                 [ring/ring-core "1.0.2"]
-                 [ring/ring-jetty-adapter "1.0.2"]]
+                 [ring/ring-core "1.1.1"]
+                 [ring/ring-jetty-adapter "1.1.1"]]
 
   :dev-dependencies [[lein-marginalia "0.7.0"]
                      ;; WebAPI support libraries.
