@@ -126,7 +126,7 @@
   [config]
   {:pre  [(map? config)]
    :post [(map? config)]}
-  (assoc-in config [:jetty :need-client-auth] true))
+  (assoc-in config [:jetty :client-auth] :need))
 
 (defn configure-database
   "Update the supplied config map with information about the database. Adds a
@@ -178,10 +178,16 @@
   config)
 
 (defn parse-config
-  "Parses the given config file (if present) and configure its various
+  "Parses the given config file/directory and configures its various
   subcomponents."
-  [file]
-  (let [config (if file (inis-to-map file) {})]
+  [path]
+  (let [file (file path)]
+    (if-not (and (.exists file)
+                 (.canRead file))
+      (throw (IllegalArgumentException.
+        (format "Configuration path '%s' must be exist and must be readable." path)))))
+
+  (let [config (if path (inis-to-map path) {})]
     (-> config
         (configure-logging!)
         (configure-commandproc-threads)
@@ -189,6 +195,12 @@
         (configure-database)
         (set-global-configuration!))))
 
+(defn on-shutdown
+  "General cleanup when a shutdown request is received."
+  []
+  ;; nothing much to do here for now, but let's at least log that we're shutting down.
+  (log/info "Shutdown request received; puppetdb exiting."))
+
 (defn -main
   [& args]
   (let [[options _]                                (cli! args)
@@ -200,12 +212,14 @@
         discard-dir                                (file mq-dir "discarded")
         globals                                    {:scf-db     db
                                                     :command-mq {:connection-string mq-addr
-                                                                 :endpoint          mq-endpoint}}
-        ring-app                                   (server/build-app globals)]
+                                                                 :endpoint          mq-endpoint}}]
 
     (when version
       (log/info (format "PuppetDB version %s" version)))
 
+    ;; Add a shutdown hook where we can handle any required cleanup
+    (pl-utils/add-shutdown-hook! on-shutdown)
+
     ;; Ensure the database is migrated to the latest version
     (sql/with-connection db
       (migrate!))
@@ -219,13 +233,16 @@
                           (mq/start-broker! (mq/build-embedded-broker mq-dir)))
           command-procs (let [nthreads (get-in config [:command-processing :threads])]
                           (log/info (format "Starting %d command processor threads" nthreads))
-                          (into [] (for [n (range nthreads)]
-                                     (future (with-error-delivery error
-                                               (load-from-mq mq-addr mq-endpoint discard-dir db))))))
-          web-app       (do
+                          (vec (for [n (range nthreads)]
+                                 (future (with-error-delivery error
+                                           (load-from-mq mq-addr mq-endpoint discard-dir db))))))
+          web-app       (let [authorized? (if-let [wl (jetty :certificate-whitelist)]
+                                            (pl-utils/cn-whitelist->authorizer wl)
+                                            (constantly true))
+                              app         (server/build-app :globals globals :authorized? authorized?)]
                           (log/info "Starting query server")
                           (future (with-error-delivery error
-                                    (jetty/run-jetty ring-app jetty))))
+                                    (jetty/run-jetty app jetty))))
           db-gc         (do
                           (log/info (format "Starting database compactor (%d minute interval)" db-gc-minutes))
                           (future (with-error-delivery error
