@@ -125,13 +125,6 @@ and their parameters which match."
          :else (throw (IllegalArgumentException.
                         (str term " is not a valid query term")))))
 
-(defn- alias-subqueries
-  "Produce distinct aliases for a list of queries, suitable for a join
-operation."
-  [queries]
-  (let [ids (range (count queries))]
-    (map #(format "%s resources_%d" %1 %2) queries ids)))
-
 ;; Join a set of predicates together with an 'and' relationship,
 ;; performing an intersection (via natural join).
 (defmethod compile-term :connective
@@ -160,6 +153,5 @@ operation."
   (when (empty? terms)
     (throw (IllegalArgumentException. (str op " requires at least one term"))))
   (let [term (compile-term (cons "or" terms))
-        query (->> (:where term)
-                   (format "NOT (%s)"))]
+        query (format "NOT (%s)" (:where term))]
     (assoc term :where query)))
