@@ -240,7 +240,7 @@ must be supplied as the value to be matched."
         replaced  (sql/update-values :certnames
                                      ["name=? AND (deactivated<? OR deactivated IS NULL)" certname timestamp]
                                      {:deactivated nil})]
-    (> (first replaced) 0)))
+    (pos? (first replaced))))
 
 (defn add-catalog-metadata!
   "Given some catalog metadata, persist it in the db"
@@ -301,7 +301,7 @@ must be supplied as the value to be matched."
         sql-params (vec (cons query resource-hashes))]
     (sql/with-query-results result-set
       sql-params
-      (into #{} (map :resource result-set)))))
+      (set (map :resource result-set)))))
 
 (defn resource-identity-hash*
   "Compute a hash for a given resource that will uniquely identify it
@@ -420,8 +420,7 @@ must be supplied as the value to be matched."
   [edge]
   {:pre  [(map? edge)]
    :post [(string? %)]}
-  (-> (edge-identity-string edge)
-      (utils/utf8-string->sha1)))
+  (utils/utf8-string->sha1 (edge-identity-string edge)))
 
 (defn add-edges!
   "Persist the given edges in the database
@@ -535,7 +534,7 @@ must be supplied as the value to be matched."
   [certname]
   (sql/with-query-results result-set
     ["SELECT catalog FROM certname_catalogs WHERE certname=?" certname]
-    (into [] (map :catalog result-set))))
+    (vec (map :catalog result-set))))
 
 (defn catalog-newer-than?
   "Returns true if the most current catalog for `certname` is more recent than
