@@ -5,8 +5,9 @@
 ;; altogether. But who has time for that?
 
 (ns com.puppetlabs.utils
-  (:import (org.ini4j Ini)
-           [org.apache.log4j PropertyConfigurator])
+  (:import [org.ini4j Ini]
+           [org.apache.log4j PropertyConfigurator]
+           [javax.naming.ldap LdapName])
   (:require [clojure.test]
             [clojure.tools.logging :as log]
             [clojure.string :as string]
@@ -15,13 +16,24 @@
             [digest]
             [fs.core :as fs]
             [ring.util.response :as rr])
-  (:use [clojure.core.incubator :only (-?>)]
+  (:use [clojure.core.incubator :only (-?> -?>>)]
         [clojure.java.io :only (reader)]
         [clojure.set :only (difference union)]
+        [clojure.stacktrace :only (print-cause-trace)]
         [clj-time.core :only [now]]
         [clj-time.format :only [formatters unparse]]
         [slingshot.slingshot :only (try+ throw+)]))
 
+;; ## I/O
+
+(defn lines
+  "Returns a sequence of lines from the given filename"
+  [filename]
+  (-> filename
+      (fs/file)
+      (reader)
+      (line-seq)))
+
 ;; ## Math
 
 (defn quotient
@@ -222,6 +234,58 @@
 
 ;; ## Logging helpers
 
+(defn catch-all-logger
+  "A logging function useful for catch-all purposes, that is, to
+  ensure that a log message gets in front of a user the best we can
+  even if that means duplicated output.
+
+  This is really only suitable for _last-ditch_ exception handling,
+  where we want to make sure an exception is logged (because nobody
+  higher up in the stack will log it for us)."
+  ([exception]
+     (catch-all-logger exception "Uncaught exception"))
+  ([exception message]
+     (print-cause-trace exception)
+     (flush)
+     (log/error exception message)))
+
+(defn set-default-uncaught-exception-handler!
+  "Sets the JVM global handler for uncaught exceptions to the supplied
+  function.
+
+  `f` is a function that takes 2 arguments (the Thread object involved
+  in the exception, and the Exception itself). The return value is
+  ignored.
+
+  If `f` isn't supplied, we default to using
+  `com.puppetlabs.utils/catch-all-logger`.
+
+  If a default handler is already defined, we throw an exception."
+  ([]
+     (set-default-uncaught-exception-handler!
+      (fn [_ e]
+        (catch-all-logger e))))
+  ([f]
+     {:pre [(fn? f)]}
+     (when (Thread/getDefaultUncaughtExceptionHandler)
+       (throw (IllegalStateException. "Default handler already defined; won't override")))
+
+     (let [handler (proxy [Thread$UncaughtExceptionHandler] []
+                     (uncaughtException [thread exception]
+                       (f thread exception)))]
+       (Thread/setDefaultUncaughtExceptionHandler handler))))
+
+(defn add-shutdown-hook!
+  "Adds a shutdown hook to the JVM runtime.
+
+  `f` is a function that takes 0 arguments; the return value is ignored.  This
+  function will be called if the JVM receiveds an interrupt signal (e.g. from
+  `kill` or CTRL-C); you can use it to log shutdown messages, handle state
+  cleanup, etc."
+  [f]
+  {:pre [(fn? f)]}
+  (.addShutdownHook (Runtime/getRuntime) (Thread. f)))
+
 (defn configure-logger-via-file!
   "Reconfigures the current logger based on the supplied configuration
   file. You can optionally supply a delay (in millis) that governs how
@@ -266,8 +330,66 @@
       (System/exit 0))
     [options posargs]))
 
+;; ## SSL Certificate handling
+
+(defn cn-for-dn
+  "Extracts the CN (common name) from an LDAP DN (distinguished name).
+
+  If more than one CN entry exists in the given DN, we return the most-specific
+  one (the one that comes last, textually). If no CN is present in the DN, we
+  return nil.
+
+  Example:
+
+      (cn-for-dn \"CN=foo.bar.com,OU=meh,C=us\")
+      \"foo.bar.com\"
+
+      (cn-for-dn \"CN=foo.bar.com,CN=baz.goo.com,OU=meh,C=us\")
+      \"baz.goo.com\"
+
+      (cn-for-dn \"OU=meh,C=us\")
+      nil"
+  [dn]
+  {:pre [(string? dn)]}
+  (-?>> dn
+        (LdapName.)
+        (.getRdns)
+        (filter #(= "CN" (.getType %)))
+        (first)
+        (.getValue)
+        (str)))
+
+(defn cn-for-cert
+  "Extract the CN from the DN of an x509 certificate. See `cn-for-dn` for details
+  on how extraction is performed.
+
+  If no CN exists in the certificate DN, nil is returned."
+  [^java.security.cert.X509Certificate cert]
+  (-> cert
+      (.getSubjectDN)
+      (.getName)
+      (cn-for-dn)))
+
 ;; ## Ring helpers
 
+(defn cn-whitelist->authorizer
+  "Given a 'whitelist' file containing allowed CNs (one per line),
+   build a function that takes a Ring request and returns true if the
+   CN contained in the client certificate appears in the whitelist.
+
+   `whitelist` can be either a local filename or a File object.
+
+   This makes use of the `:ssl-client-cn` request parameter. See
+   `com.puppetlabs.middleware/wrap-with-certificate-cn`."
+  [whitelist]
+  {:pre  [(or (string? whitelist)
+              (instance? java.io.File whitelist))]
+   :post [(fn? %)]}
+  (let [allowed? (set (lines whitelist))]
+    (fn [{:keys [ssl-client-cn scheme] :as req}]
+      (or (= scheme :http)
+          (allowed? ssl-client-cn)))))
+
 (defn acceptable-content-type
   "Returns a boolean indicating whether the `candidate` mime type
   matches any of those listed in `header`, an Accept header."
@@ -340,8 +462,7 @@
   "Grabs the number of available CPUs for the local host"
   []
   {:post [(pos? %)]}
-  (-> (Runtime/getRuntime)
-      (.availableProcessors)))
+  (.availableProcessors (Runtime/getRuntime)))
 
 ;; ## META-INF parsing
 
